Welcome to MasterPiece documentation!
=====================================

.. image:: _static/masterpiece.png
    :alt: Masterpiece - A Piece of Work
    :width: 400px
    :height: 300px

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   masterpiece/index

.. include:: ../../README.rst

.. include:: ../../LICENSE.rst

.. include:: ../../CONTRIBUTING.rst

.. include:: ../../CHANGELOG.rst

.. include:: ../../TODO.rst

.. include:: tutorial.rst
.. include:: plugintutorial.rst
	     

Classes
-------

.. inheritance-diagram:: masterpiece.masterpiece 
    masterpiece.composite.Composite 
    masterpiece.application.Application 
    masterpiece.plugin.Plugin 
    masterpiece.plugmaster.PlugMaster 
    masterpiece.argmaestro.ArgMaestro 
    masterpiece.log.Log 
    masterpiece.treevisualizer.TreeVisualizer
   :parts: 1






Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
